==> keycloak-model-map-hot-rod-20.0.4-sources.jar: org/keycloak/models/map/storage/hotRod/authorization/HotRodPolicyEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.authorization;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodPolicyEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.authorization.model.Policy.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntity.class;
    }
    @Override
    public String getCacheName() {
        return "authz";
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntity.HotRodPolicyEntitySchema.INSTANCE;
    }
}

==> keycloak-model-map-hot-rod-22.0.5-sources.jar: org/keycloak/models/map/storage/hotRod/authorization/HotRodPolicyEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.authorization;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateHotRodEntityImplementationsProcessor")
public class HotRodPolicyEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.authorization.model.Policy.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntity.class;
    }
    @Override
    public String getCacheName() {
        return "authz";
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodPolicyEntity.HotRodPolicyEntitySchema.INSTANCE;
    }
}
